==> zio-aws-swf_3-5.17.129.3-sources.jar: zio/aws/swf/model/CountPendingDecisionTasksResponse.scala <==
package zio.aws.swf.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.swf.model.primitives.{Truncated, Count}
import scala.jdk.CollectionConverters.*
final case class CountPendingDecisionTasksResponse(
    count: Count,
    truncated: Option[Truncated] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse = {
    import CountPendingDecisionTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
      .builder()
      .count(Count.unwrap(count): Integer)
      .optionallyWith(
        truncated.map(value => Truncated.unwrap(value): java.lang.Boolean)
      )(_.truncated)
      .build()
  }
  def asReadOnly: zio.aws.swf.model.CountPendingDecisionTasksResponse.ReadOnly =
    zio.aws.swf.model.CountPendingDecisionTasksResponse.wrap(buildAwsValue())
}
object CountPendingDecisionTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.CountPendingDecisionTasksResponse =
      zio.aws.swf.model
        .CountPendingDecisionTasksResponse(count, truncated.map(value => value))
    def count: Count
    def truncated: Option[Truncated]
    def getCount: ZIO[Any, Nothing, Count] = ZIO.succeed(count)
    def getTruncated: ZIO[Any, AwsError, Truncated] =
      AwsError.unwrapOptionField("truncated", truncated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
  ) extends zio.aws.swf.model.CountPendingDecisionTasksResponse.ReadOnly {
    override val count: Count = zio.aws.swf.model.primitives.Count(impl.count())
    override val truncated: Option[Truncated] = scala
      .Option(impl.truncated())
      .map(value => zio.aws.swf.model.primitives.Truncated(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
  ): zio.aws.swf.model.CountPendingDecisionTasksResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-swf_3-5.20.37.1-sources.jar: zio/aws/swf/model/CountPendingDecisionTasksResponse.scala <==
package zio.aws.swf.model
import zio.aws.swf.model.primitives.{Truncated, Count}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class CountPendingDecisionTasksResponse(
    count: Count,
    truncated: Optional[Truncated] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse = {
    import CountPendingDecisionTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
      .builder()
      .count(Count.unwrap(count): Integer)
      .optionallyWith(
        truncated.map(value => Truncated.unwrap(value): java.lang.Boolean)
      )(_.truncated)
      .build()
  }
  def asReadOnly: zio.aws.swf.model.CountPendingDecisionTasksResponse.ReadOnly =
    zio.aws.swf.model.CountPendingDecisionTasksResponse.wrap(buildAwsValue())
}
object CountPendingDecisionTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.CountPendingDecisionTasksResponse =
      zio.aws.swf.model
        .CountPendingDecisionTasksResponse(count, truncated.map(value => value))
    def count: Count
    def truncated: Optional[Truncated]
    def getCount: ZIO[Any, Nothing, Count] = ZIO.succeed(count)
    def getTruncated: ZIO[Any, AwsError, Truncated] =
      AwsError.unwrapOptionField("truncated", truncated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
  ) extends zio.aws.swf.model.CountPendingDecisionTasksResponse.ReadOnly {
    override val count: Count = zio.aws.swf.model.primitives.Count(impl.count())
    override val truncated: Optional[Truncated] = zio.aws.core.internal
      .optionalFromNullable(impl.truncated())
      .map(value => zio.aws.swf.model.primitives.Truncated(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.CountPendingDecisionTasksResponse
  ): zio.aws.swf.model.CountPendingDecisionTasksResponse.ReadOnly = new Wrapper(
    impl
  )
}
